pub struct GnssFixSolution {Show 19 fields
pub fix_type: GnssFixType,
pub gnss_fix_ok: bool,
pub differential_solution: bool,
pub carrier_solution: u8,
pub invalid_llh: bool,
pub num_satellites_used: u8,
pub longitude: Angle,
pub latitude: Angle,
pub height_ellipsoid: Length,
pub height_msl: Length,
pub velocity_north: Velocity,
pub velocity_east: Velocity,
pub velocity_down: Velocity,
pub ground_speed: Velocity,
pub heading_motion: Angle,
pub heading_vehicle: Angle,
pub magnetic_declination: Angle,
pub psm_state: u8,
pub correction_age_bucket: u8,
}Expand description
Precision notes for GNSS payloads.
| Field(s) | UBX/source resolution | f32 precision at relevant scale | f64 precision | Recommendation |
|---|---|---|---|---|
latitude, longitude | 1e-7 deg | at 32 deg: 3.81e-6 deg (0.42 m lat, 0.36 m lon); at 180 deg: 1.53e-5 deg (1.70 m lat) | ~1e-14 deg | f64 |
height_* | 1 mm | at 1000 m: 6.1e-5 m; at 10000 m: 9.8e-4 m | ~1e-13..1e-12 m | f32 |
velocity_*, ground_speed | 1 mm/s | at 100 m/s: 7.6e-6 m/s; at 1000 m/s: 6.1e-5 m/s | ~1e-14..1e-13 m/s | f32 |
heading_* | 1e-5 deg | at 360 deg: 3.05e-5 deg | ~5.7e-14 deg | f32 |
magnetic_declination | 1e-2 deg | at 20 deg: 1.91e-6 deg | ~3.6e-15 deg | f32 |
accuracy.* | 1 mm, 1 mm/s, 1e-5 deg, 1 ns, 0.01 | already below or close to source quantization | much smaller than source quantization | f32 |
| satellite/signal angles and residuals | 1 deg, 0.1 m | already below source quantization | much smaller than source quantization | f32 |
The only fields that materially benefit from f64 in practice are the
absolute geodetic coordinates, because path planning and local projection
often subtract nearby fixes and f32 loses sub-meter detail there.
Fields
fix_type: GnssFixTypegnss_fix_ok: booldifferential_solution: boolcarrier_solution: u8invalid_llh: boolnum_satellites_used: u8longitude: Anglelatitude: Angleheight_ellipsoid: Lengthheight_msl: Lengthvelocity_north: Velocityvelocity_east: Velocityvelocity_down: Velocityground_speed: Velocityheading_motion: Angleheading_vehicle: Anglemagnetic_declination: Anglepsm_state: u8correction_age_bucket: u8Trait Implementations
Sourceimpl<'__de, __Context> BorrowDecode<'__de, __Context> for GnssFixSolution
impl<'__de, __Context> BorrowDecode<'__de, __Context> for GnssFixSolution
Sourcefn borrow_decode<__D: BorrowDecoder<'__de, Context = __Context>>(
decoder: &mut __D,
) -> Result<Self, DecodeError>
fn borrow_decode<__D: BorrowDecoder<'__de, Context = __Context>>( decoder: &mut __D, ) -> Result<Self, DecodeError>
Attempt to decode this type with the given BorrowDecode.
Sourceimpl Clone for GnssFixSolution
impl Clone for GnssFixSolution
Sourcefn clone(&self) -> GnssFixSolution
fn clone(&self) -> GnssFixSolution
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GnssFixSolution
impl Debug for GnssFixSolution
Sourceimpl<__Context> Decode<__Context> for GnssFixSolution
impl<__Context> Decode<__Context> for GnssFixSolution
Sourceimpl Default for GnssFixSolution
impl Default for GnssFixSolution
Sourceimpl<'de> Deserialize<'de> for GnssFixSolution
impl<'de> Deserialize<'de> for GnssFixSolution
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Encode for GnssFixSolution
impl Encode for GnssFixSolution
Sourceimpl PartialEq for GnssFixSolution
impl PartialEq for GnssFixSolution
Sourceimpl Serialize for GnssFixSolution
impl Serialize for GnssFixSolution
impl Copy for GnssFixSolution
impl StructuralPartialEq for GnssFixSolution